#
# spec file for package python-brotlipy
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without python2
Name:           python-brotlipy
Version:        0.7.0
Release:        150300.3.3.1
Summary:        Python binding to the Brotli library
License:        MIT
URL:            https://github.com/python-hyper/brotlipy
Source0:        https://files.pythonhosted.org/packages/source/b/brotlipy/brotlipy-%{version}.tar.gz
# Copy of https://github.com/google/brotli/tree/46c1a881b41bb638c76247558aa04b1591af3aa7/tests/testdata
Source1:        testdata.tgz
Source2:        https://raw.githubusercontent.com/python-hyper/brotlipy/master/test/conftest.py
Patch0:         merged_pr_94.patch
Patch1:         pr_154-brotli-v1.patch
# PATCH-FIX-UPSTREAM danilo.spinella@suse.com bsc#1175825
# integer overflow when input chunk is larger than 2GiB
Patch2:         CVE-2020-8927.patch
BuildRequires:  %{python_module cffi >= 1.0.0}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  libbrotli-devel
BuildRequires:  python-rpm-macros
Requires:       python-cffi >= 1.0.0
%if %{with python2}
BuildRequires:  python-enum34
%endif
%ifpython2
Requires:       python-enum34
%endif
%python_subpackages

%description
This library contains Python bindings for the reference Brotli
encoder/decoder.
This allows Python software to use the Brotli compression algorithm
directly from Python code.

%prep
%setup -q -n brotlipy-%{version}
%autopatch -p1
# Remove unnecessary dependency on stdc++
# See https://github.com/python-hyper/brotlipy/pull/151
sed -i 's/libraries.append.*stdc++.*$/pass/' src/brotli/build.py

cp %{SOURCE2} test/
cd libbrotli
mkdir -p tests
cd tests
tar -xzf %{SOURCE1}

%build
export CFLAGS="%{optflags}"
export USE_SHARED_BROTLI=1
%python_build

%install
%python_install
%{python_expand rm -f %{buildroot}%{$python_sitearch}/brotli/build.py* %{buildroot}%{$python_sitearch}/brotli/__pycache__/build.*
%fdupes %{buildroot}%{$python_sitearch}
}

%check
# the skipped tests are benchmarks which can be flaky in OBS
%pytest_arch -k 'not (test_streaming_compression or test_streaming_compression_flush)'

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitearch}/brotli
%{python_sitearch}/brotlipy-%{version}-py*.egg-info

%changelog
* Mon Sep 11 2023 danilo.spinella@suse.com
- Fix CVE-2020-8927, integer overflow when input chunk is larger than 2GiB,
  bsc#1175825
  * CVE-2020-8927.patch
* Mon Mar 16 2020 tchvatal@suse.com
- Fix build without python2
* Fri Nov  1 2019 jayvdb@gmail.com
- Replace builtin libbrotli v0.6 with system libbrotli 1.x with patches:
  - merged_pr_94.patch
  - pr_154-brotli-v1.patch
- Remove build dependency stdc++
- Remove brotli/build.py from installed package
* Fri Mar 22 2019 tchvatal@suse.com
- Skip failing tests in OBS due to the speed of CPUs there
* Thu Feb 28 2019 jayvdb@gmail.com
- Add missing runtime dependency enum34
- Use %%license, and add the libbrotli LICENSE
- Activate test suite
* Sun Feb 25 2018 aloisio@gmx.com
- Update to 0.7.0 (no changelog supplied)
* Wed Mar  8 2017 aloisio@gmx.com
- Converted to single-spec
* Tue Dec 27 2016 aloisio@gmx.com
- Initial version (0.6.0)
